# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gravtools/gui/MainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.setEnabled(True)
        MainWindow.resize(1337, 751)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_37 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_37.setObjectName("verticalLayout_37")
        self.tabWidget_Main = QtWidgets.QTabWidget(self.centralwidget)
        self.tabWidget_Main.setTabPosition(QtWidgets.QTabWidget.East)
        self.tabWidget_Main.setMovable(True)
        self.tabWidget_Main.setObjectName("tabWidget_Main")
        self.tab_main_stations = QtWidgets.QWidget()
        self.tab_main_stations.setObjectName("tab_main_stations")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tab_main_stations)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox_filter_options = QtWidgets.QGroupBox(self.tab_main_stations)
        self.groupBox_filter_options.setEnabled(False)
        self.groupBox_filter_options.setFlat(False)
        self.groupBox_filter_options.setCheckable(False)
        self.groupBox_filter_options.setObjectName("groupBox_filter_options")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_filter_options)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.checkBox_filter_observed_stat_only = QtWidgets.QCheckBox(self.groupBox_filter_options)
        self.checkBox_filter_observed_stat_only.setChecked(True)
        self.checkBox_filter_observed_stat_only.setObjectName("checkBox_filter_observed_stat_only")
        self.verticalLayout_2.addWidget(self.checkBox_filter_observed_stat_only)
        self.label = QtWidgets.QLabel(self.groupBox_filter_options)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.lineEdit_filter_stat_name = QtWidgets.QLineEdit(self.groupBox_filter_options)
        self.lineEdit_filter_stat_name.setText("")
        self.lineEdit_filter_stat_name.setObjectName("lineEdit_filter_stat_name")
        self.verticalLayout_2.addWidget(self.lineEdit_filter_stat_name)
        self.verticalLayout_3.addWidget(self.groupBox_filter_options)
        self.groupBox_stations_map_view_options = QtWidgets.QGroupBox(self.tab_main_stations)
        self.groupBox_stations_map_view_options.setEnabled(False)
        self.groupBox_stations_map_view_options.setObjectName("groupBox_stations_map_view_options")
        self.verticalLayout_31 = QtWidgets.QVBoxLayout(self.groupBox_stations_map_view_options)
        self.verticalLayout_31.setObjectName("verticalLayout_31")
        self.checkBox_stations_map_show_stat_name_labels = QtWidgets.QCheckBox(self.groupBox_stations_map_view_options)
        self.checkBox_stations_map_show_stat_name_labels.setChecked(True)
        self.checkBox_stations_map_show_stat_name_labels.setObjectName("checkBox_stations_map_show_stat_name_labels")
        self.verticalLayout_31.addWidget(self.checkBox_stations_map_show_stat_name_labels)
        self.checkBox_stations_plot_obs_map = QtWidgets.QCheckBox(self.groupBox_stations_map_view_options)
        self.checkBox_stations_plot_obs_map.setObjectName("checkBox_stations_plot_obs_map")
        self.verticalLayout_31.addWidget(self.checkBox_stations_plot_obs_map)
        self.comboBox_stations_plot_obs_map_surveys = QtWidgets.QComboBox(self.groupBox_stations_map_view_options)
        self.comboBox_stations_plot_obs_map_surveys.setEnabled(False)
        self.comboBox_stations_plot_obs_map_surveys.setObjectName("comboBox_stations_plot_obs_map_surveys")
        self.verticalLayout_31.addWidget(self.comboBox_stations_plot_obs_map_surveys)
        self.verticalLayout_3.addWidget(self.groupBox_stations_map_view_options)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.tab_Widget_Stations = QtWidgets.QTabWidget(self.tab_main_stations)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tab_Widget_Stations.sizePolicy().hasHeightForWidth())
        self.tab_Widget_Stations.setSizePolicy(sizePolicy)
        self.tab_Widget_Stations.setObjectName("tab_Widget_Stations")
        self.tab_Stations_Table = QtWidgets.QWidget()
        self.tab_Stations_Table.setObjectName("tab_Stations_Table")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.tab_Stations_Table)
        self.verticalLayout.setObjectName("verticalLayout")
        self.tableView_Stations = QtWidgets.QTableView(self.tab_Stations_Table)
        self.tableView_Stations.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.tableView_Stations.setObjectName("tableView_Stations")
        self.tableView_Stations.horizontalHeader().setCascadingSectionResizes(True)
        self.verticalLayout.addWidget(self.tableView_Stations)
        self.tab_Widget_Stations.addTab(self.tab_Stations_Table, "")
        self.tab_stations_map = QtWidgets.QWidget()
        self.tab_stations_map.setObjectName("tab_stations_map")
        self.verticalLayout_30 = QtWidgets.QVBoxLayout(self.tab_stations_map)
        self.verticalLayout_30.setObjectName("verticalLayout_30")
        self.GraphicsLayoutWidget_stations_map = GraphicsLayoutWidget(self.tab_stations_map)
        self.GraphicsLayoutWidget_stations_map.setObjectName("GraphicsLayoutWidget_stations_map")
        self.verticalLayout_30.addWidget(self.GraphicsLayoutWidget_stations_map)
        self.tab_Widget_Stations.addTab(self.tab_stations_map, "")
        self.horizontalLayout_2.addWidget(self.tab_Widget_Stations)
        self.horizontalLayout_2.setStretch(0, 1)
        self.horizontalLayout_2.setStretch(1, 4)
        self.verticalLayout_4.addLayout(self.horizontalLayout_2)
        self.tabWidget_Main.addTab(self.tab_main_stations, "")
        self.tab_main_gravimeters = QtWidgets.QWidget()
        self.tab_main_gravimeters.setObjectName("tab_main_gravimeters")
        self.verticalLayout_28 = QtWidgets.QVBoxLayout(self.tab_main_gravimeters)
        self.verticalLayout_28.setObjectName("verticalLayout_28")
        self.splitter_gravimeters = QtWidgets.QSplitter(self.tab_main_gravimeters)
        self.splitter_gravimeters.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_gravimeters.setObjectName("splitter_gravimeters")
        self.layoutWidget = QtWidgets.QWidget(self.splitter_gravimeters)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_40 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_40.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_40.setObjectName("verticalLayout_40")
        self.treeWidget_gravimeters = QtWidgets.QTreeWidget(self.layoutWidget)
        self.treeWidget_gravimeters.setHeaderHidden(False)
        self.treeWidget_gravimeters.setColumnCount(2)
        self.treeWidget_gravimeters.setObjectName("treeWidget_gravimeters")
        self.verticalLayout_40.addWidget(self.treeWidget_gravimeters)
        self.pushButton_delete_gravimeter = QtWidgets.QPushButton(self.layoutWidget)
        self.pushButton_delete_gravimeter.setEnabled(False)
        self.pushButton_delete_gravimeter.setObjectName("pushButton_delete_gravimeter")
        self.verticalLayout_40.addWidget(self.pushButton_delete_gravimeter)
        self.tabWidget_gravimeters = QtWidgets.QTabWidget(self.splitter_gravimeters)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget_gravimeters.sizePolicy().hasHeightForWidth())
        self.tabWidget_gravimeters.setSizePolicy(sizePolicy)
        self.tabWidget_gravimeters.setObjectName("tabWidget_gravimeters")
        self.tab_gravimeter_info = QtWidgets.QWidget()
        self.tab_gravimeter_info.setObjectName("tab_gravimeter_info")
        self.verticalLayout_42 = QtWidgets.QVBoxLayout(self.tab_gravimeter_info)
        self.verticalLayout_42.setObjectName("verticalLayout_42")
        self.formLayout_12 = QtWidgets.QFormLayout()
        self.formLayout_12.setObjectName("formLayout_12")
        self.label_19 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_19.setObjectName("label_19")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_19)
        self.label_gravi_manufacturer = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_manufacturer.setText("")
        self.label_gravi_manufacturer.setObjectName("label_gravi_manufacturer")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_gravi_manufacturer)
        self.label_20 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_20.setObjectName("label_20")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_20)
        self.label_gravi_type = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_type.setText("")
        self.label_gravi_type.setObjectName("label_gravi_type")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_gravi_type)
        self.label_21 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_21.setObjectName("label_21")
        self.formLayout_12.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_21)
        self.label_gravi_serial_number = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_serial_number.setText("")
        self.label_gravi_serial_number.setObjectName("label_gravi_serial_number")
        self.formLayout_12.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_gravi_serial_number)
        self.label_25 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_25.setObjectName("label_25")
        self.formLayout_12.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_25)
        self.label_gravi_code = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_code.setText("")
        self.label_gravi_code.setObjectName("label_gravi_code")
        self.formLayout_12.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.label_gravi_code)
        self.label_22 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_22.setObjectName("label_22")
        self.formLayout_12.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_22)
        self.label_gravi_height_offset = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_height_offset.setText("")
        self.label_gravi_height_offset.setObjectName("label_gravi_height_offset")
        self.formLayout_12.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.label_gravi_height_offset)
        self.label_23 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_23.setObjectName("label_23")
        self.formLayout_12.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.label_23)
        self.label_gravi_data_source = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_data_source.setText("")
        self.label_gravi_data_source.setObjectName("label_gravi_data_source")
        self.formLayout_12.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.label_gravi_data_source)
        self.label_24 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_24.setObjectName("label_24")
        self.formLayout_12.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.label_24)
        self.label_gravi_data_source_type = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_data_source_type.setText("")
        self.label_gravi_data_source_type.setObjectName("label_gravi_data_source_type")
        self.formLayout_12.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.label_gravi_data_source_type)
        self.label_26 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_26.setObjectName("label_26")
        self.formLayout_12.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.label_26)
        self.label_gravi_num_scale_factors = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_num_scale_factors.setText("")
        self.label_gravi_num_scale_factors.setObjectName("label_gravi_num_scale_factors")
        self.formLayout_12.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.label_gravi_num_scale_factors)
        self.label_28 = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_28.setObjectName("label_28")
        self.formLayout_12.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.label_28)
        self.label_gravi_description = QtWidgets.QLabel(self.tab_gravimeter_info)
        self.label_gravi_description.setText("")
        self.label_gravi_description.setWordWrap(True)
        self.label_gravi_description.setObjectName("label_gravi_description")
        self.formLayout_12.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.label_gravi_description)
        self.verticalLayout_42.addLayout(self.formLayout_12)
        self.tabWidget_gravimeters.addTab(self.tab_gravimeter_info, "")
        self.tab_gravimeter_scale = QtWidgets.QWidget()
        self.tab_gravimeter_scale.setObjectName("tab_gravimeter_scale")
        self.verticalLayout_41 = QtWidgets.QVBoxLayout(self.tab_gravimeter_scale)
        self.verticalLayout_41.setObjectName("verticalLayout_41")
        self.tableView_gravimeters_scale = QtWidgets.QTableView(self.tab_gravimeter_scale)
        self.tableView_gravimeters_scale.setObjectName("tableView_gravimeters_scale")
        self.verticalLayout_41.addWidget(self.tableView_gravimeters_scale)
        self.tabWidget_gravimeters.addTab(self.tab_gravimeter_scale, "")
        self.verticalLayout_28.addWidget(self.splitter_gravimeters)
        self.tabWidget_Main.addTab(self.tab_main_gravimeters, "")
        self.tab_main_observations = QtWidgets.QWidget()
        self.tab_main_observations.setObjectName("tab_main_observations")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.tab_main_observations)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.splitter_obs = QtWidgets.QSplitter(self.tab_main_observations)
        self.splitter_obs.setToolTipDuration(1)
        self.splitter_obs.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_obs.setObjectName("splitter_obs")
        self.layoutWidget1 = QtWidgets.QWidget(self.splitter_obs)
        self.layoutWidget1.setObjectName("layoutWidget1")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.layoutWidget1)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.treeWidget_observations = QtWidgets.QTreeWidget(self.layoutWidget1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.treeWidget_observations.sizePolicy().hasHeightForWidth())
        self.treeWidget_observations.setSizePolicy(sizePolicy)
        self.treeWidget_observations.setMinimumSize(QtCore.QSize(280, 0))
        self.treeWidget_observations.setHeaderHidden(True)
        self.treeWidget_observations.setObjectName("treeWidget_observations")
        self.treeWidget_observations.header().setVisible(False)
        self.treeWidget_observations.header().setStretchLastSection(True)
        self.verticalLayout_5.addWidget(self.treeWidget_observations)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.pushButton_obs_collaps_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.pushButton_obs_collaps_all.setObjectName("pushButton_obs_collaps_all")
        self.horizontalLayout_3.addWidget(self.pushButton_obs_collaps_all)
        self.pushButton_obs_expand_all = QtWidgets.QPushButton(self.layoutWidget1)
        self.pushButton_obs_expand_all.setObjectName("pushButton_obs_expand_all")
        self.horizontalLayout_3.addWidget(self.pushButton_obs_expand_all)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.groupBox_obs_data_manipulation = QtWidgets.QGroupBox(self.layoutWidget1)
        self.groupBox_obs_data_manipulation.setEnabled(False)
        self.groupBox_obs_data_manipulation.setObjectName("groupBox_obs_data_manipulation")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.groupBox_obs_data_manipulation)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.pushButton_obs_apply_autoselect_current_data = QtWidgets.QPushButton(self.groupBox_obs_data_manipulation)
        self.pushButton_obs_apply_autoselect_current_data.setObjectName("pushButton_obs_apply_autoselect_current_data")
        self.verticalLayout_10.addWidget(self.pushButton_obs_apply_autoselect_current_data)
        self.pushButton_obs_comp_setup_data = QtWidgets.QPushButton(self.groupBox_obs_data_manipulation)
        self.pushButton_obs_comp_setup_data.setObjectName("pushButton_obs_comp_setup_data")
        self.verticalLayout_10.addWidget(self.pushButton_obs_comp_setup_data)
        self.pushButton_obs_run_estimation = QtWidgets.QPushButton(self.groupBox_obs_data_manipulation)
        self.pushButton_obs_run_estimation.setObjectName("pushButton_obs_run_estimation")
        self.verticalLayout_10.addWidget(self.pushButton_obs_run_estimation)
        self.verticalLayout_5.addWidget(self.groupBox_obs_data_manipulation)
        self.groupBox_obs_view_options = QtWidgets.QGroupBox(self.layoutWidget1)
        self.groupBox_obs_view_options.setEnabled(False)
        self.groupBox_obs_view_options.setObjectName("groupBox_obs_view_options")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.groupBox_obs_view_options)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.checkBox_obs_plot_reduced_observations = QtWidgets.QCheckBox(self.groupBox_obs_view_options)
        self.checkBox_obs_plot_reduced_observations.setChecked(True)
        self.checkBox_obs_plot_reduced_observations.setObjectName("checkBox_obs_plot_reduced_observations")
        self.verticalLayout_9.addWidget(self.checkBox_obs_plot_reduced_observations)
        self.checkBox_obs_plot_setup_data = QtWidgets.QCheckBox(self.groupBox_obs_view_options)
        self.checkBox_obs_plot_setup_data.setChecked(True)
        self.checkBox_obs_plot_setup_data.setObjectName("checkBox_obs_plot_setup_data")
        self.verticalLayout_9.addWidget(self.checkBox_obs_plot_setup_data)
        self.verticalLayout_5.addWidget(self.groupBox_obs_view_options)
        self.tabWidget_observations = QtWidgets.QTabWidget(self.splitter_obs)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget_observations.sizePolicy().hasHeightForWidth())
        self.tabWidget_observations.setSizePolicy(sizePolicy)
        self.tabWidget_observations.setObjectName("tabWidget_observations")
        self.tab_observations_plots = QtWidgets.QWidget()
        self.tab_observations_plots.setObjectName("tab_observations_plots")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.tab_observations_plots)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.GraphicsLayoutWidget_observations = GraphicsLayoutWidget(self.tab_observations_plots)
        self.GraphicsLayoutWidget_observations.setObjectName("GraphicsLayoutWidget_observations")
        self.verticalLayout_8.addWidget(self.GraphicsLayoutWidget_observations)
        self.tabWidget_observations.addTab(self.tab_observations_plots, "")
        self.tab_observations_table = QtWidgets.QWidget()
        self.tab_observations_table.setObjectName("tab_observations_table")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.tab_observations_table)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.tableView_observations = QtWidgets.QTableView(self.tab_observations_table)
        self.tableView_observations.setObjectName("tableView_observations")
        self.verticalLayout_6.addWidget(self.tableView_observations)
        self.tabWidget_observations.addTab(self.tab_observations_table, "")
        self.tab_surveys = QtWidgets.QWidget()
        self.tab_surveys.setObjectName("tab_surveys")
        self.verticalLayout_43 = QtWidgets.QVBoxLayout(self.tab_surveys)
        self.verticalLayout_43.setObjectName("verticalLayout_43")
        self.tableView_surveys = QtWidgets.QTableView(self.tab_surveys)
        self.tableView_surveys.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.tableView_surveys.setObjectName("tableView_surveys")
        self.verticalLayout_43.addWidget(self.tableView_surveys)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.pushButton_surveys_enable_all = QtWidgets.QPushButton(self.tab_surveys)
        self.pushButton_surveys_enable_all.setObjectName("pushButton_surveys_enable_all")
        self.horizontalLayout_6.addWidget(self.pushButton_surveys_enable_all)
        self.pushButton_surveys_disable_all = QtWidgets.QPushButton(self.tab_surveys)
        self.pushButton_surveys_disable_all.setObjectName("pushButton_surveys_disable_all")
        self.horizontalLayout_6.addWidget(self.pushButton_surveys_disable_all)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem1)
        self.verticalLayout_43.addLayout(self.horizontalLayout_6)
        self.tabWidget_observations.addTab(self.tab_surveys, "")
        self.tab_observations_setups = QtWidgets.QWidget()
        self.tab_observations_setups.setObjectName("tab_observations_setups")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.tab_observations_setups)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.tableView_observations_setups = QtWidgets.QTableView(self.tab_observations_setups)
        self.tableView_observations_setups.setObjectName("tableView_observations_setups")
        self.verticalLayout_11.addWidget(self.tableView_observations_setups)
        self.groupBox_obs_setups_applied_corrections = QtWidgets.QGroupBox(self.tab_observations_setups)
        self.groupBox_obs_setups_applied_corrections.setObjectName("groupBox_obs_setups_applied_corrections")
        self.formLayout_6 = QtWidgets.QFormLayout(self.groupBox_obs_setups_applied_corrections)
        self.formLayout_6.setObjectName("formLayout_6")
        self.label_obs_setups_1 = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_1.setObjectName("label_obs_setups_1")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_obs_setups_1)
        self.label_obs_setups_tidal_corr = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_tidal_corr.setText("")
        self.label_obs_setups_tidal_corr.setObjectName("label_obs_setups_tidal_corr")
        self.formLayout_6.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_obs_setups_tidal_corr)
        self.label_obs_setups_2 = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_2.setObjectName("label_obs_setups_2")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_obs_setups_2)
        self.label_obs_setups_ref_height = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_ref_height.setText("")
        self.label_obs_setups_ref_height.setObjectName("label_obs_setups_ref_height")
        self.formLayout_6.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_obs_setups_ref_height)
        self.label_27 = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_27.setObjectName("label_27")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_27)
        self.label_obs_setups_3 = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_3.setObjectName("label_obs_setups_3")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_obs_setups_3)
        self.label_obs_setups_atm_pres_corr = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_atm_pres_corr.setText("")
        self.label_obs_setups_atm_pres_corr.setObjectName("label_obs_setups_atm_pres_corr")
        self.formLayout_6.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.label_obs_setups_atm_pres_corr)
        self.label_obs_setups_scale_corr = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_scale_corr.setText("")
        self.label_obs_setups_scale_corr.setObjectName("label_obs_setups_scale_corr")
        self.formLayout_6.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_obs_setups_scale_corr)
        self.label_29 = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_29.setObjectName("label_29")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.label_29)
        self.label_obs_setups_oceanload_corr = QtWidgets.QLabel(self.groupBox_obs_setups_applied_corrections)
        self.label_obs_setups_oceanload_corr.setText("")
        self.label_obs_setups_oceanload_corr.setObjectName("label_obs_setups_oceanload_corr")
        self.formLayout_6.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.label_obs_setups_oceanload_corr)
        self.verticalLayout_11.addWidget(self.groupBox_obs_setups_applied_corrections)
        self.tabWidget_observations.addTab(self.tab_observations_setups, "")
        self.verticalLayout_7.addWidget(self.splitter_obs)
        self.tabWidget_Main.addTab(self.tab_main_observations, "")
        self.tab_main_results = QtWidgets.QWidget()
        self.tab_main_results.setToolTipDuration(2)
        self.tab_main_results.setObjectName("tab_main_results")
        self.verticalLayout_14 = QtWidgets.QVBoxLayout(self.tab_main_results)
        self.verticalLayout_14.setObjectName("verticalLayout_14")
        self.splitter_results = QtWidgets.QSplitter(self.tab_main_results)
        self.splitter_results.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_results.setObjectName("splitter_results")
        self.verticalLayoutWidget = QtWidgets.QWidget(self.splitter_results)
        self.verticalLayoutWidget.setObjectName("verticalLayoutWidget")
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout_12.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_12.setObjectName("verticalLayout_12")
        self.groupBox_results_lsm_runs = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        self.groupBox_results_lsm_runs.setObjectName("groupBox_results_lsm_runs")
        self.verticalLayout_16 = QtWidgets.QVBoxLayout(self.groupBox_results_lsm_runs)
        self.verticalLayout_16.setObjectName("verticalLayout_16")
        self.comboBox_results_lsm_run_selection = QtWidgets.QComboBox(self.groupBox_results_lsm_runs)
        self.comboBox_results_lsm_run_selection.setObjectName("comboBox_results_lsm_run_selection")
        self.verticalLayout_16.addWidget(self.comboBox_results_lsm_run_selection)
        self.label_results_lsm_run_comment_display = QtWidgets.QLabel(self.groupBox_results_lsm_runs)
        self.label_results_lsm_run_comment_display.setText("")
        self.label_results_lsm_run_comment_display.setObjectName("label_results_lsm_run_comment_display")
        self.verticalLayout_16.addWidget(self.label_results_lsm_run_comment_display)
        self.pushButton_results_delete_lsm_run = QtWidgets.QPushButton(self.groupBox_results_lsm_runs)
        self.pushButton_results_delete_lsm_run.setObjectName("pushButton_results_delete_lsm_run")
        self.verticalLayout_16.addWidget(self.pushButton_results_delete_lsm_run)
        self.pushButton_results_delete_all_lsm_runs = QtWidgets.QPushButton(self.groupBox_results_lsm_runs)
        self.pushButton_results_delete_all_lsm_runs.setObjectName("pushButton_results_delete_all_lsm_runs")
        self.verticalLayout_16.addWidget(self.pushButton_results_delete_all_lsm_runs)
        self.verticalLayout_12.addWidget(self.groupBox_results_lsm_runs)
        self.groupBox_results_data_selection = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        self.groupBox_results_data_selection.setObjectName("groupBox_results_data_selection")
        self.verticalLayout_17 = QtWidgets.QVBoxLayout(self.groupBox_results_data_selection)
        self.verticalLayout_17.setObjectName("verticalLayout_17")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_2 = QtWidgets.QLabel(self.groupBox_results_data_selection)
        self.label_2.setObjectName("label_2")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_2)
        self.comboBox_results_selection_station = QtWidgets.QComboBox(self.groupBox_results_data_selection)
        self.comboBox_results_selection_station.setObjectName("comboBox_results_selection_station")
        self.comboBox_results_selection_station.addItem("")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.comboBox_results_selection_station)
        self.label_5 = QtWidgets.QLabel(self.groupBox_results_data_selection)
        self.label_5.setObjectName("label_5")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_5)
        self.comboBox_results_selection_survey = QtWidgets.QComboBox(self.groupBox_results_data_selection)
        self.comboBox_results_selection_survey.setObjectName("comboBox_results_selection_survey")
        self.comboBox_results_selection_survey.addItem("")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.comboBox_results_selection_survey)
        self.verticalLayout_17.addLayout(self.formLayout)
        self.verticalLayout_12.addWidget(self.groupBox_results_data_selection)
        self.groupBox_gis_data = QtWidgets.QGroupBox(self.verticalLayoutWidget)
        self.groupBox_gis_data.setObjectName("groupBox_gis_data")
        self.verticalLayout_36 = QtWidgets.QVBoxLayout(self.groupBox_gis_data)
        self.verticalLayout_36.setObjectName("verticalLayout_36")
        self.pushButton_results_export_shapefile = QtWidgets.QPushButton(self.groupBox_gis_data)
        self.pushButton_results_export_shapefile.setObjectName("pushButton_results_export_shapefile")
        self.verticalLayout_36.addWidget(self.pushButton_results_export_shapefile)
        self.formLayout_7 = QtWidgets.QFormLayout()
        self.formLayout_7.setObjectName("formLayout_7")
        self.verticalLayout_36.addLayout(self.formLayout_7)
        self.verticalLayout_12.addWidget(self.groupBox_gis_data)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_12.addItem(spacerItem2)
        self.tabWidget_results = QtWidgets.QTabWidget(self.splitter_results)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget_results.sizePolicy().hasHeightForWidth())
        self.tabWidget_results.setSizePolicy(sizePolicy)
        self.tabWidget_results.setObjectName("tabWidget_results")
        self.tab_results_info = QtWidgets.QWidget()
        self.tab_results_info.setObjectName("tab_results_info")
        self.verticalLayout_23 = QtWidgets.QVBoxLayout(self.tab_results_info)
        self.verticalLayout_23.setObjectName("verticalLayout_23")
        self.verticalLayout_22 = QtWidgets.QVBoxLayout()
        self.verticalLayout_22.setObjectName("verticalLayout_22")
        self.groupBox_results_info = QtWidgets.QGroupBox(self.tab_results_info)
        self.groupBox_results_info.setObjectName("groupBox_results_info")
        self.verticalLayout_21 = QtWidgets.QVBoxLayout(self.groupBox_results_info)
        self.verticalLayout_21.setObjectName("verticalLayout_21")
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_3 = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_3.setObjectName("label_3")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_3)
        self.label_results_adjustment_method = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_results_adjustment_method.setMinimumSize(QtCore.QSize(100, 0))
        self.label_results_adjustment_method.setText("")
        self.label_results_adjustment_method.setObjectName("label_results_adjustment_method")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_results_adjustment_method)
        self.label_results_time_and_date = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_results_time_and_date.setMinimumSize(QtCore.QSize(100, 0))
        self.label_results_time_and_date.setText("")
        self.label_results_time_and_date.setObjectName("label_results_time_and_date")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_results_time_and_date)
        self.label_8 = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_8.setObjectName("label_8")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_8)
        self.label_results_number_of_iterations = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_results_number_of_iterations.setText("")
        self.label_results_number_of_iterations.setObjectName("label_results_number_of_iterations")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_results_number_of_iterations)
        self.label_10 = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_10.setObjectName("label_10")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.label_10)
        self.label_results_comment = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_results_comment.setMinimumSize(QtCore.QSize(100, 0))
        self.label_results_comment.setText("")
        self.label_results_comment.setObjectName("label_results_comment")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.label_results_comment)
        self.label_4 = QtWidgets.QLabel(self.groupBox_results_info)
        self.label_4.setObjectName("label_4")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_4)
        self.verticalLayout_21.addLayout(self.formLayout_2)
        self.verticalLayout_22.addWidget(self.groupBox_results_info)
        self.groupBox_results_statistics = QtWidgets.QGroupBox(self.tab_results_info)
        self.groupBox_results_statistics.setObjectName("groupBox_results_statistics")
        self.verticalLayout_24 = QtWidgets.QVBoxLayout(self.groupBox_results_statistics)
        self.verticalLayout_24.setObjectName("verticalLayout_24")
        self.formLayout_3 = QtWidgets.QFormLayout()
        self.formLayout_3.setObjectName("formLayout_3")
        self.label_9 = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_9.setObjectName("label_9")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_9)
        self.label_results_sig0 = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_results_sig0.setMinimumSize(QtCore.QSize(100, 0))
        self.label_results_sig0.setText("")
        self.label_results_sig0.setObjectName("label_results_sig0")
        self.formLayout_3.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_results_sig0)
        self.label_6 = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_6.setObjectName("label_6")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_6)
        self.label_results_goodness_of_fit_test_status = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_results_goodness_of_fit_test_status.setText("")
        self.label_results_goodness_of_fit_test_status.setObjectName("label_results_goodness_of_fit_test_status")
        self.formLayout_3.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_results_goodness_of_fit_test_status)
        self.label_7 = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_7.setObjectName("label_7")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_7)
        self.label_results_number_of_outliers = QtWidgets.QLabel(self.groupBox_results_statistics)
        self.label_results_number_of_outliers.setText("")
        self.label_results_number_of_outliers.setObjectName("label_results_number_of_outliers")
        self.formLayout_3.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.label_results_number_of_outliers)
        self.verticalLayout_24.addLayout(self.formLayout_3)
        self.verticalLayout_22.addWidget(self.groupBox_results_statistics)
        self.groupBox_results_lsm_run_log = QtWidgets.QGroupBox(self.tab_results_info)
        self.groupBox_results_lsm_run_log.setObjectName("groupBox_results_lsm_run_log")
        self.verticalLayout_20 = QtWidgets.QVBoxLayout(self.groupBox_results_lsm_run_log)
        self.verticalLayout_20.setObjectName("verticalLayout_20")
        self.plainTextEdit_results_log = QtWidgets.QPlainTextEdit(self.groupBox_results_lsm_run_log)
        self.plainTextEdit_results_log.setReadOnly(True)
        self.plainTextEdit_results_log.setObjectName("plainTextEdit_results_log")
        self.verticalLayout_20.addWidget(self.plainTextEdit_results_log)
        self.verticalLayout_22.addWidget(self.groupBox_results_lsm_run_log)
        self.verticalLayout_23.addLayout(self.verticalLayout_22)
        self.tabWidget_results.addTab(self.tab_results_info, "")
        self.tab_results_obs_table = QtWidgets.QWidget()
        self.tab_results_obs_table.setObjectName("tab_results_obs_table")
        self.verticalLayout_15 = QtWidgets.QVBoxLayout(self.tab_results_obs_table)
        self.verticalLayout_15.setObjectName("verticalLayout_15")
        self.tableView_results_observations = QtWidgets.QTableView(self.tab_results_obs_table)
        self.tableView_results_observations.setObjectName("tableView_results_observations")
        self.verticalLayout_15.addWidget(self.tableView_results_observations)
        self.tabWidget_results.addTab(self.tab_results_obs_table, "")
        self.tab_results_obs_plots = QtWidgets.QWidget()
        self.tab_results_obs_plots.setObjectName("tab_results_obs_plots")
        self.verticalLayout_38 = QtWidgets.QVBoxLayout(self.tab_results_obs_plots)
        self.verticalLayout_38.setObjectName("verticalLayout_38")
        self.graphicsLayoutWidget_results_observations_plots = GraphicsLayoutWidget(self.tab_results_obs_plots)
        self.graphicsLayoutWidget_results_observations_plots.setObjectName("graphicsLayoutWidget_results_observations_plots")
        self.verticalLayout_38.addWidget(self.graphicsLayoutWidget_results_observations_plots)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.groupBox_plot_settings = QtWidgets.QGroupBox(self.tab_results_obs_plots)
        self.groupBox_plot_settings.setObjectName("groupBox_plot_settings")
        self.verticalLayout_25 = QtWidgets.QVBoxLayout(self.groupBox_plot_settings)
        self.verticalLayout_25.setObjectName("verticalLayout_25")
        self.formLayout_4 = QtWidgets.QFormLayout()
        self.formLayout_4.setObjectName("formLayout_4")
        self.label_results_obs_plot_selec_data_column = QtWidgets.QLabel(self.groupBox_plot_settings)
        self.label_results_obs_plot_selec_data_column.setObjectName("label_results_obs_plot_selec_data_column")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_results_obs_plot_selec_data_column)
        self.comboBox_results_obs_plot_select_data_column = QtWidgets.QComboBox(self.groupBox_plot_settings)
        self.comboBox_results_obs_plot_select_data_column.setObjectName("comboBox_results_obs_plot_select_data_column")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.comboBox_results_obs_plot_select_data_column)
        self.verticalLayout_25.addLayout(self.formLayout_4)
        self.radioButton_results_obs_plot_timeseries = QtWidgets.QRadioButton(self.groupBox_plot_settings)
        self.radioButton_results_obs_plot_timeseries.setChecked(True)
        self.radioButton_results_obs_plot_timeseries.setObjectName("radioButton_results_obs_plot_timeseries")
        self.verticalLayout_25.addWidget(self.radioButton_results_obs_plot_timeseries)
        self.radioButton_results_obs_plot_histogram = QtWidgets.QRadioButton(self.groupBox_plot_settings)
        self.radioButton_results_obs_plot_histogram.setObjectName("radioButton_results_obs_plot_histogram")
        self.verticalLayout_25.addWidget(self.radioButton_results_obs_plot_histogram)
        self.horizontalLayout.addWidget(self.groupBox_plot_settings)
        self.groupBox_histogram_settings = QtWidgets.QGroupBox(self.tab_results_obs_plots)
        self.groupBox_histogram_settings.setEnabled(False)
        self.groupBox_histogram_settings.setObjectName("groupBox_histogram_settings")
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(self.groupBox_histogram_settings)
        self.verticalLayout_13.setObjectName("verticalLayout_13")
        self.formLayout_8 = QtWidgets.QFormLayout()
        self.formLayout_8.setObjectName("formLayout_8")
        self.label_11 = QtWidgets.QLabel(self.groupBox_histogram_settings)
        self.label_11.setObjectName("label_11")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_11)
        self.comboBox_results_obs_plot_hist_method = QtWidgets.QComboBox(self.groupBox_histogram_settings)
        self.comboBox_results_obs_plot_hist_method.setObjectName("comboBox_results_obs_plot_hist_method")
        self.formLayout_8.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.comboBox_results_obs_plot_hist_method)
        self.label_results_obs_plot_number_bins = QtWidgets.QLabel(self.groupBox_histogram_settings)
        self.label_results_obs_plot_number_bins.setObjectName("label_results_obs_plot_number_bins")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_results_obs_plot_number_bins)
        self.spinBox_results_obs_plot_number_bins = QtWidgets.QSpinBox(self.groupBox_histogram_settings)
        self.spinBox_results_obs_plot_number_bins.setMinimum(2)
        self.spinBox_results_obs_plot_number_bins.setMaximum(1000)
        self.spinBox_results_obs_plot_number_bins.setProperty("value", 10)
        self.spinBox_results_obs_plot_number_bins.setObjectName("spinBox_results_obs_plot_number_bins")
        self.formLayout_8.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.spinBox_results_obs_plot_number_bins)
        self.verticalLayout_13.addLayout(self.formLayout_8)
        self.checkBox_results_obs_plot_show_outliers = QtWidgets.QCheckBox(self.groupBox_histogram_settings)
        self.checkBox_results_obs_plot_show_outliers.setEnabled(False)
        self.checkBox_results_obs_plot_show_outliers.setObjectName("checkBox_results_obs_plot_show_outliers")
        self.verticalLayout_13.addWidget(self.checkBox_results_obs_plot_show_outliers)
        self.horizontalLayout.addWidget(self.groupBox_histogram_settings)
        self.verticalLayout_38.addLayout(self.horizontalLayout)
        self.tabWidget_results.addTab(self.tab_results_obs_plots, "")
        self.tab_results_drift = QtWidgets.QWidget()
        self.tab_results_drift.setObjectName("tab_results_drift")
        self.verticalLayout_18 = QtWidgets.QVBoxLayout(self.tab_results_drift)
        self.verticalLayout_18.setObjectName("verticalLayout_18")
        self.tableView_results_drift = QtWidgets.QTableView(self.tab_results_drift)
        self.tableView_results_drift.setObjectName("tableView_results_drift")
        self.verticalLayout_18.addWidget(self.tableView_results_drift)
        self.tabWidget_results.addTab(self.tab_results_drift, "")
        self.tab_results_driftplot = QtWidgets.QWidget()
        self.tab_results_driftplot.setObjectName("tab_results_driftplot")
        self.verticalLayout_29 = QtWidgets.QVBoxLayout(self.tab_results_driftplot)
        self.verticalLayout_29.setObjectName("verticalLayout_29")
        self.verticalLayout_27 = QtWidgets.QVBoxLayout()
        self.verticalLayout_27.setObjectName("verticalLayout_27")
        self.graphicsLayoutWidget_results_drift_plot = GraphicsLayoutWidget(self.tab_results_driftplot)
        self.graphicsLayoutWidget_results_drift_plot.setObjectName("graphicsLayoutWidget_results_drift_plot")
        self.verticalLayout_27.addWidget(self.graphicsLayoutWidget_results_drift_plot)
        self.groupBox_results_drift_plot = QtWidgets.QGroupBox(self.tab_results_driftplot)
        self.groupBox_results_drift_plot.setEnabled(True)
        self.groupBox_results_drift_plot.setObjectName("groupBox_results_drift_plot")
        self.verticalLayout_26 = QtWidgets.QVBoxLayout(self.groupBox_results_drift_plot)
        self.verticalLayout_26.setObjectName("verticalLayout_26")
        self.formLayout_5 = QtWidgets.QFormLayout()
        self.formLayout_5.setObjectName("formLayout_5")
        self.label_results_drift_plot_v_offset = QtWidgets.QLabel(self.groupBox_results_drift_plot)
        self.label_results_drift_plot_v_offset.setEnabled(False)
        self.label_results_drift_plot_v_offset.setObjectName("label_results_drift_plot_v_offset")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_results_drift_plot_v_offset)
        self.spinBox_results_drift_plot_v_offset = QtWidgets.QSpinBox(self.groupBox_results_drift_plot)
        self.spinBox_results_drift_plot_v_offset.setEnabled(False)
        self.spinBox_results_drift_plot_v_offset.setMinimum(-1000)
        self.spinBox_results_drift_plot_v_offset.setMaximum(1000)
        self.spinBox_results_drift_plot_v_offset.setObjectName("spinBox_results_drift_plot_v_offset")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.spinBox_results_drift_plot_v_offset)
        self.verticalLayout_26.addLayout(self.formLayout_5)
        self.verticalLayout_27.addWidget(self.groupBox_results_drift_plot)
        self.verticalLayout_29.addLayout(self.verticalLayout_27)
        self.tabWidget_results.addTab(self.tab_results_driftplot, "")
        self.tab_results_stat_table = QtWidgets.QWidget()
        self.tab_results_stat_table.setObjectName("tab_results_stat_table")
        self.verticalLayout_39 = QtWidgets.QVBoxLayout(self.tab_results_stat_table)
        self.verticalLayout_39.setObjectName("verticalLayout_39")
        self.tableView_results_stations = QtWidgets.QTableView(self.tab_results_stat_table)
        self.tableView_results_stations.setObjectName("tableView_results_stations")
        self.verticalLayout_39.addWidget(self.tableView_results_stations)
        self.groupBox_results_stations_statistics = QtWidgets.QGroupBox(self.tab_results_stat_table)
        self.groupBox_results_stations_statistics.setObjectName("groupBox_results_stations_statistics")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.groupBox_results_stations_statistics)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout_19 = QtWidgets.QVBoxLayout()
        self.verticalLayout_19.setObjectName("verticalLayout_19")
        self.label_12 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_12.setObjectName("label_12")
        self.verticalLayout_19.addWidget(self.label_12)
        self.comboBox_results_stations_statistics_select_col = QtWidgets.QComboBox(self.groupBox_results_stations_statistics)
        self.comboBox_results_stations_statistics_select_col.setObjectName("comboBox_results_stations_statistics_select_col")
        self.verticalLayout_19.addWidget(self.comboBox_results_stations_statistics_select_col)
        self.horizontalLayout_4.addLayout(self.verticalLayout_19)
        self.formLayout_9 = QtWidgets.QFormLayout()
        self.formLayout_9.setObjectName("formLayout_9")
        self.label_13 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_13.setObjectName("label_13")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_13)
        self.label_results_stations_statistics_mean = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_results_stations_statistics_mean.setText("")
        self.label_results_stations_statistics_mean.setObjectName("label_results_stations_statistics_mean")
        self.formLayout_9.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_results_stations_statistics_mean)
        self.label_14 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_14.setObjectName("label_14")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_14)
        self.label_results_stations_statistics_std = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_results_stations_statistics_std.setText("")
        self.label_results_stations_statistics_std.setObjectName("label_results_stations_statistics_std")
        self.formLayout_9.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_results_stations_statistics_std)
        self.horizontalLayout_4.addLayout(self.formLayout_9)
        self.formLayout_10 = QtWidgets.QFormLayout()
        self.formLayout_10.setObjectName("formLayout_10")
        self.label_15 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_15.setObjectName("label_15")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_15)
        self.label_results_stations_statistics_min = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_results_stations_statistics_min.setText("")
        self.label_results_stations_statistics_min.setObjectName("label_results_stations_statistics_min")
        self.formLayout_10.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label_results_stations_statistics_min)
        self.label_16 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_16.setObjectName("label_16")
        self.formLayout_10.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_16)
        self.label_results_stations_statistics_max = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_results_stations_statistics_max.setText("")
        self.label_results_stations_statistics_max.setObjectName("label_results_stations_statistics_max")
        self.formLayout_10.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label_results_stations_statistics_max)
        self.horizontalLayout_4.addLayout(self.formLayout_10)
        self.formLayout_11 = QtWidgets.QFormLayout()
        self.formLayout_11.setObjectName("formLayout_11")
        self.label_17 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_17.setObjectName("label_17")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_17)
        self.label__results_stations_statistics_median = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label__results_stations_statistics_median.setText("")
        self.label__results_stations_statistics_median.setObjectName("label__results_stations_statistics_median")
        self.formLayout_11.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.label__results_stations_statistics_median)
        self.label_18 = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label_18.setObjectName("label_18")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_18)
        self.label__results_stations_statistics_iqr = QtWidgets.QLabel(self.groupBox_results_stations_statistics)
        self.label__results_stations_statistics_iqr.setText("")
        self.label__results_stations_statistics_iqr.setObjectName("label__results_stations_statistics_iqr")
        self.formLayout_11.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.label__results_stations_statistics_iqr)
        self.horizontalLayout_4.addLayout(self.formLayout_11)
        self.verticalLayout_39.addWidget(self.groupBox_results_stations_statistics)
        self.tabWidget_results.addTab(self.tab_results_stat_table, "")
        self.tab_results_correlation_matrix = QtWidgets.QWidget()
        self.tab_results_correlation_matrix.setObjectName("tab_results_correlation_matrix")
        self.verticalLayout_32 = QtWidgets.QVBoxLayout(self.tab_results_correlation_matrix)
        self.verticalLayout_32.setObjectName("verticalLayout_32")
        self.tableView_results_correlation_matrix = QtWidgets.QTableView(self.tab_results_correlation_matrix)
        self.tableView_results_correlation_matrix.setObjectName("tableView_results_correlation_matrix")
        self.verticalLayout_32.addWidget(self.tableView_results_correlation_matrix)
        self.tabWidget_results.addTab(self.tab_results_correlation_matrix, "")
        self.tab_vg_table = QtWidgets.QWidget()
        self.tab_vg_table.setObjectName("tab_vg_table")
        self.verticalLayout_33 = QtWidgets.QVBoxLayout(self.tab_vg_table)
        self.verticalLayout_33.setObjectName("verticalLayout_33")
        self.tableView_results_vg_table = QtWidgets.QTableView(self.tab_vg_table)
        self.tableView_results_vg_table.setObjectName("tableView_results_vg_table")
        self.verticalLayout_33.addWidget(self.tableView_results_vg_table)
        self.tabWidget_results.addTab(self.tab_vg_table, "")
        self.tab_vg_plot = QtWidgets.QWidget()
        self.tab_vg_plot.setObjectName("tab_vg_plot")
        self.verticalLayout_35 = QtWidgets.QVBoxLayout(self.tab_vg_plot)
        self.verticalLayout_35.setObjectName("verticalLayout_35")
        self.graphicsLayoutWidget_results_vg_plot = GraphicsLayoutWidget(self.tab_vg_plot)
        self.graphicsLayoutWidget_results_vg_plot.setObjectName("graphicsLayoutWidget_results_vg_plot")
        self.verticalLayout_35.addWidget(self.graphicsLayoutWidget_results_vg_plot)
        self.groupBox_results_vg_plot_settings = QtWidgets.QGroupBox(self.tab_vg_plot)
        self.groupBox_results_vg_plot_settings.setObjectName("groupBox_results_vg_plot_settings")
        self.verticalLayout_34 = QtWidgets.QVBoxLayout(self.groupBox_results_vg_plot_settings)
        self.verticalLayout_34.setObjectName("verticalLayout_34")
        self.checkBox_results_vg_plot_show_residuals = QtWidgets.QCheckBox(self.groupBox_results_vg_plot_settings)
        self.checkBox_results_vg_plot_show_residuals.setChecked(True)
        self.checkBox_results_vg_plot_show_residuals.setObjectName("checkBox_results_vg_plot_show_residuals")
        self.verticalLayout_34.addWidget(self.checkBox_results_vg_plot_show_residuals)
        self.radioButton_results_vg_plot_details = QtWidgets.QRadioButton(self.groupBox_results_vg_plot_settings)
        self.radioButton_results_vg_plot_details.setChecked(True)
        self.radioButton_results_vg_plot_details.setObjectName("radioButton_results_vg_plot_details")
        self.buttonGroup_results_vg_plot_type_selection = QtWidgets.QButtonGroup(MainWindow)
        self.buttonGroup_results_vg_plot_type_selection.setObjectName("buttonGroup_results_vg_plot_type_selection")
        self.buttonGroup_results_vg_plot_type_selection.addButton(self.radioButton_results_vg_plot_details)
        self.verticalLayout_34.addWidget(self.radioButton_results_vg_plot_details)
        self.radioButton_results_vg_plot_full_polynomial = QtWidgets.QRadioButton(self.groupBox_results_vg_plot_settings)
        self.radioButton_results_vg_plot_full_polynomial.setObjectName("radioButton_results_vg_plot_full_polynomial")
        self.buttonGroup_results_vg_plot_type_selection.addButton(self.radioButton_results_vg_plot_full_polynomial)
        self.verticalLayout_34.addWidget(self.radioButton_results_vg_plot_full_polynomial)
        self.verticalLayout_35.addWidget(self.groupBox_results_vg_plot_settings)
        self.tabWidget_results.addTab(self.tab_vg_plot, "")
        self.verticalLayout_14.addWidget(self.splitter_results)
        self.tabWidget_Main.addTab(self.tab_main_results, "")
        self.verticalLayout_37.addWidget(self.tabWidget_Main)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1337, 22))
        self.menubar.setObjectName("menubar")
        self.menu_File = QtWidgets.QMenu(self.menubar)
        self.menu_File.setObjectName("menu_File")
        self.menuAdd_Survey = QtWidgets.QMenu(self.menu_File)
        self.menuAdd_Survey.setEnabled(False)
        self.menuAdd_Survey.setObjectName("menuAdd_Survey")
        self.menu_Add_Stations = QtWidgets.QMenu(self.menu_File)
        self.menu_Add_Stations.setEnabled(False)
        self.menu_Add_Stations.setObjectName("menu_Add_Stations")
        self.menu_Add_Gravimeters = QtWidgets.QMenu(self.menu_File)
        self.menu_Add_Gravimeters.setEnabled(False)
        self.menu_Add_Gravimeters.setObjectName("menu_Add_Gravimeters")
        self.menu_Observations = QtWidgets.QMenu(self.menubar)
        self.menu_Observations.setEnabled(False)
        self.menu_Observations.setTearOffEnabled(False)
        self.menu_Observations.setObjectName("menu_Observations")
        self.menuEstimation_settings = QtWidgets.QMenu(self.menubar)
        self.menuEstimation_settings.setEnabled(True)
        self.menuEstimation_settings.setObjectName("menuEstimation_settings")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        self.menuCorrections = QtWidgets.QMenu(self.menubar)
        self.menuCorrections.setObjectName("menuCorrections")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setInputMethodHints(QtCore.Qt.ImhNone)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.action_New_Campaign = QtWidgets.QAction(MainWindow)
        self.action_New_Campaign.setObjectName("action_New_Campaign")
        self.action_Save_Campaign = QtWidgets.QAction(MainWindow)
        self.action_Save_Campaign.setEnabled(False)
        self.action_Save_Campaign.setObjectName("action_Save_Campaign")
        self.action_Load_Campaign = QtWidgets.QAction(MainWindow)
        self.action_Load_Campaign.setEnabled(True)
        self.action_Load_Campaign.setObjectName("action_Load_Campaign")
        self.action_Add_Stations = QtWidgets.QAction(MainWindow)
        self.action_Add_Stations.setEnabled(False)
        self.action_Add_Stations.setObjectName("action_Add_Stations")
        self.action_Exit = QtWidgets.QAction(MainWindow)
        self.action_Exit.setObjectName("action_Exit")
        self.action_Edit_Observations = QtWidgets.QAction(MainWindow)
        self.action_Edit_Observations.setEnabled(True)
        self.action_Edit_Observations.setObjectName("action_Edit_Observations")
        self.actionResiduals = QtWidgets.QAction(MainWindow)
        self.actionResiduals.setObjectName("actionResiduals")
        self.actionEstimates = QtWidgets.QAction(MainWindow)
        self.actionEstimates.setObjectName("actionEstimates")
        self.action_Corrections = QtWidgets.QAction(MainWindow)
        self.action_Corrections.setEnabled(True)
        self.action_Corrections.setObjectName("action_Corrections")
        self.actionShow_Stations = QtWidgets.QAction(MainWindow)
        self.actionShow_Stations.setObjectName("actionShow_Stations")
        self.action_from_CG5_observation_file = QtWidgets.QAction(MainWindow)
        self.action_from_CG5_observation_file.setObjectName("action_from_CG5_observation_file")
        self.action_from_BEV_observation_file = QtWidgets.QAction(MainWindow)
        self.action_from_BEV_observation_file.setEnabled(False)
        self.action_from_BEV_observation_file.setObjectName("action_from_BEV_observation_file")
        self.action_Autoselection_settings = QtWidgets.QAction(MainWindow)
        self.action_Autoselection_settings.setObjectName("action_Autoselection_settings")
        self.action_Estimation_settings = QtWidgets.QAction(MainWindow)
        self.action_Estimation_settings.setEnabled(True)
        self.action_Estimation_settings.setObjectName("action_Estimation_settings")
        self.actionEstimate_long_term_drift = QtWidgets.QAction(MainWindow)
        self.actionEstimate_long_term_drift.setEnabled(True)
        self.actionEstimate_long_term_drift.setObjectName("actionEstimate_long_term_drift")
        self.action_Export_Results = QtWidgets.QAction(MainWindow)
        self.action_Export_Results.setEnabled(False)
        self.action_Export_Results.setObjectName("action_Export_Results")
        self.action_Change_output_directory = QtWidgets.QAction(MainWindow)
        self.action_Change_output_directory.setEnabled(False)
        self.action_Change_output_directory.setObjectName("action_Change_output_directory")
        self.action_Options = QtWidgets.QAction(MainWindow)
        self.action_Options.setObjectName("action_Options")
        self.action_Setup_data_options = QtWidgets.QAction(MainWindow)
        self.action_Setup_data_options.setEnabled(True)
        self.action_Setup_data_options.setObjectName("action_Setup_data_options")
        self.action_Flag_observations = QtWidgets.QAction(MainWindow)
        self.action_Flag_observations.setObjectName("action_Flag_observations")
        self.action_Change_Campaign_name = QtWidgets.QAction(MainWindow)
        self.action_Change_Campaign_name.setEnabled(False)
        self.action_Change_Campaign_name.setObjectName("action_Change_Campaign_name")
        self.action_About = QtWidgets.QAction(MainWindow)
        self.action_About.setObjectName("action_About")
        self.action_License = QtWidgets.QAction(MainWindow)
        self.action_License.setObjectName("action_License")
        self.action_Gis_Export_settings = QtWidgets.QAction(MainWindow)
        self.action_Gis_Export_settings.setEnabled(False)
        self.action_Gis_Export_settings.setObjectName("action_Gis_Export_settings")
        self.action_from_oesgn_table = QtWidgets.QAction(MainWindow)
        self.action_from_oesgn_table.setObjectName("action_from_oesgn_table")
        self.action_from_csv_file = QtWidgets.QAction(MainWindow)
        self.action_from_csv_file.setObjectName("action_from_csv_file")
        self.action_Correction_time_series = QtWidgets.QAction(MainWindow)
        self.action_Correction_time_series.setObjectName("action_Correction_time_series")
        self.action_gravimeters_from_json_file = QtWidgets.QAction(MainWindow)
        self.action_gravimeters_from_json_file.setObjectName("action_gravimeters_from_json_file")
        self.action_from_CG6_observation_files = QtWidgets.QAction(MainWindow)
        self.action_from_CG6_observation_files.setObjectName("action_from_CG6_observation_files")
        self.action_Calculate_drift = QtWidgets.QAction(MainWindow)
        self.action_Calculate_drift.setObjectName("action_Calculate_drift")
        self.menuAdd_Survey.addAction(self.action_from_CG5_observation_file)
        self.menuAdd_Survey.addAction(self.action_from_CG6_observation_files)
        self.menuAdd_Survey.addAction(self.action_from_BEV_observation_file)
        self.menu_Add_Stations.addAction(self.action_from_oesgn_table)
        self.menu_Add_Stations.addAction(self.action_from_csv_file)
        self.menu_Add_Gravimeters.addAction(self.action_gravimeters_from_json_file)
        self.menu_File.addAction(self.action_New_Campaign)
        self.menu_File.addAction(self.action_Change_output_directory)
        self.menu_File.addAction(self.action_Change_Campaign_name)
        self.menu_File.addAction(self.action_Save_Campaign)
        self.menu_File.addAction(self.action_Load_Campaign)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.menuAdd_Survey.menuAction())
        self.menu_File.addAction(self.menu_Add_Stations.menuAction())
        self.menu_File.addAction(self.menu_Add_Gravimeters.menuAction())
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Export_Results)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Options)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Exit)
        self.menu_Observations.addSeparator()
        self.menu_Observations.addAction(self.action_Autoselection_settings)
        self.menu_Observations.addAction(self.action_Setup_data_options)
        self.menu_Observations.addAction(self.action_Flag_observations)
        self.menu_Observations.addAction(self.action_Calculate_drift)
        self.menuEstimation_settings.addAction(self.action_Estimation_settings)
        self.menuEstimation_settings.addAction(self.action_Gis_Export_settings)
        self.menuHelp.addAction(self.action_About)
        self.menuCorrections.addAction(self.action_Corrections)
        self.menuCorrections.addAction(self.action_Correction_time_series)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Observations.menuAction())
        self.menubar.addAction(self.menuEstimation_settings.menuAction())
        self.menubar.addAction(self.menuCorrections.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget_Main.setCurrentIndex(2)
        self.tab_Widget_Stations.setCurrentIndex(0)
        self.tabWidget_gravimeters.setCurrentIndex(0)
        self.tabWidget_observations.setCurrentIndex(0)
        self.tabWidget_results.setCurrentIndex(0)
        self.radioButton_results_obs_plot_histogram.toggled['bool'].connect(self.groupBox_histogram_settings.setEnabled) # type: ignore
        self.checkBox_stations_plot_obs_map.toggled['bool'].connect(self.comboBox_stations_plot_obs_map_surveys.setEnabled) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "GravTools"))
        self.groupBox_filter_options.setToolTip(_translate("MainWindow", "Display options for stations"))
        self.groupBox_filter_options.setTitle(_translate("MainWindow", "Filter Options"))
        self.checkBox_filter_observed_stat_only.setToolTip(_translate("MainWindow", "Display only stations that were observed in this campaign. "))
        self.checkBox_filter_observed_stat_only.setText(_translate("MainWindow", "Observed only"))
        self.label.setText(_translate("MainWindow", "Station name filter (regex)"))
        self.groupBox_stations_map_view_options.setTitle(_translate("MainWindow", "Map view options"))
        self.checkBox_stations_map_show_stat_name_labels.setText(_translate("MainWindow", "Show station name labels"))
        self.checkBox_stations_plot_obs_map.setToolTip(_translate("MainWindow", "<html><head/><body><p>Plot observations in terms of lines in the station plot according to the selection below.</p></body></html>"))
        self.checkBox_stations_plot_obs_map.setText(_translate("MainWindow", "Plot observations"))
        self.comboBox_stations_plot_obs_map_surveys.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select whether observations of all surveys, or of a selected survey should be plotted in the station map.</p></body></html>"))
        self.tab_Widget_Stations.setTabText(self.tab_Widget_Stations.indexOf(self.tab_Stations_Table), _translate("MainWindow", "Table"))
        self.tab_Widget_Stations.setTabText(self.tab_Widget_Stations.indexOf(self.tab_stations_map), _translate("MainWindow", "Map"))
        self.tabWidget_Main.setTabText(self.tabWidget_Main.indexOf(self.tab_main_stations), _translate("MainWindow", "Stations"))
        self.treeWidget_gravimeters.headerItem().setText(0, _translate("MainWindow", "Type"))
        self.treeWidget_gravimeters.headerItem().setText(1, _translate("MainWindow", "S/N"))
        self.pushButton_delete_gravimeter.setText(_translate("MainWindow", "Delete"))
        self.label_19.setToolTip(_translate("MainWindow", "Manufacturer of instrument."))
        self.label_19.setText(_translate("MainWindow", "Manufacturer:"))
        self.label_gravi_manufacturer.setToolTip(_translate("MainWindow", "Manufacturer of instrument."))
        self.label_20.setToolTip(_translate("MainWindow", "Gravimeter type."))
        self.label_20.setText(_translate("MainWindow", "Type:"))
        self.label_gravi_type.setToolTip(_translate("MainWindow", "Gravimeter type."))
        self.label_21.setToolTip(_translate("MainWindow", "Serial number."))
        self.label_21.setText(_translate("MainWindow", "Serial number:"))
        self.label_gravi_serial_number.setToolTip(_translate("MainWindow", "Serial number."))
        self.label_25.setToolTip(_translate("MainWindow", "Short instrument code."))
        self.label_25.setText(_translate("MainWindow", "Code:"))
        self.label_gravi_code.setToolTip(_translate("MainWindow", "Short instrument code."))
        self.label_22.setToolTip(_translate("MainWindow", "<html><head/><body><p>Heigh offset in meters between instrument top and sensor level (negative, if the sensor is below the top).</p></body></html>"))
        self.label_22.setText(_translate("MainWindow", "Height offset [m]:"))
        self.label_gravi_height_offset.setToolTip(_translate("MainWindow", "<html><head/><body><p>Heigh offset in meters between instrument top and sensor level (negative, if the sensor is below the top).</p></body></html>"))
        self.label_23.setToolTip(_translate("MainWindow", "Source of the gravimeter data. Either the name of the survey the data was taken from (ob. file), or the name of the gravimeter file."))
        self.label_23.setText(_translate("MainWindow", "Data source:"))
        self.label_gravi_data_source.setToolTip(_translate("MainWindow", "Source of the gravimeter data. Either the name of the survey the data was taken from (ob. file), or the name of the gravimeter file."))
        self.label_24.setToolTip(_translate("MainWindow", "Type of the gravimeter data source. "))
        self.label_24.setText(_translate("MainWindow", "Data source type:"))
        self.label_gravi_data_source_type.setToolTip(_translate("MainWindow", "Type of the gravimeter data source. "))
        self.label_26.setToolTip(_translate("MainWindow", "Number of scale factor items."))
        self.label_26.setText(_translate("MainWindow", "Number of scale factors:"))
        self.label_gravi_num_scale_factors.setToolTip(_translate("MainWindow", "Number of scale factor items."))
        self.label_28.setText(_translate("MainWindow", "Description:"))
        self.tabWidget_gravimeters.setTabText(self.tabWidget_gravimeters.indexOf(self.tab_gravimeter_info), _translate("MainWindow", "Info"))
        self.tabWidget_gravimeters.setTabText(self.tabWidget_gravimeters.indexOf(self.tab_gravimeter_scale), _translate("MainWindow", "Scale Table"))
        self.tabWidget_Main.setTabText(self.tabWidget_Main.indexOf(self.tab_main_gravimeters), _translate("MainWindow", "Gravimeters"))
        self.treeWidget_observations.setSortingEnabled(False)
        self.treeWidget_observations.headerItem().setText(0, _translate("MainWindow", "Survey"))
        self.treeWidget_observations.headerItem().setText(1, _translate("MainWindow", "Station"))
        self.treeWidget_observations.headerItem().setText(2, _translate("MainWindow", "#Obs"))
        self.pushButton_obs_collaps_all.setText(_translate("MainWindow", "Collape all"))
        self.pushButton_obs_expand_all.setText(_translate("MainWindow", "Expand all"))
        self.groupBox_obs_data_manipulation.setTitle(_translate("MainWindow", "Data manipulation"))
        self.pushButton_obs_apply_autoselect_current_data.setToolTip(_translate("MainWindow", "Activate/deactivate observations of the current selected survey or setup according to the auto-selection options."))
        self.pushButton_obs_apply_autoselect_current_data.setText(_translate("MainWindow", "Apply Autoselection"))
        self.pushButton_obs_comp_setup_data.setToolTip(_translate("MainWindow", "Compute variance-weighted mean of active observations for all setups in campaign."))
        self.pushButton_obs_comp_setup_data.setText(_translate("MainWindow", "Compute setup data for campaign"))
        self.pushButton_obs_run_estimation.setToolTip(_translate("MainWindow", "Run parameter estimation according to the estimation settings."))
        self.pushButton_obs_run_estimation.setText(_translate("MainWindow", "Run estimation"))
        self.groupBox_obs_view_options.setTitle(_translate("MainWindow", "View Options"))
        self.checkBox_obs_plot_reduced_observations.setToolTip(_translate("MainWindow", "Plot reduced observatio data, if availble."))
        self.checkBox_obs_plot_reduced_observations.setText(_translate("MainWindow", "Plot reduced observations"))
        self.checkBox_obs_plot_setup_data.setToolTip(_translate("MainWindow", "Plot variance-weighted mean of observation data for all setups."))
        self.checkBox_obs_plot_setup_data.setText(_translate("MainWindow", "Plot setup data"))
        self.tabWidget_observations.setTabText(self.tabWidget_observations.indexOf(self.tab_observations_plots), _translate("MainWindow", "Observation plots"))
        self.tabWidget_observations.setTabText(self.tabWidget_observations.indexOf(self.tab_observations_table), _translate("MainWindow", "Observations table"))
        self.pushButton_surveys_enable_all.setToolTip(_translate("MainWindow", "<html><head/><body><p>Activate all surveys in the campaign.</p></body></html>"))
        self.pushButton_surveys_enable_all.setText(_translate("MainWindow", "Activate all"))
        self.pushButton_surveys_disable_all.setToolTip(_translate("MainWindow", "<html><head/><body><p>Deactivate all surveys in the campaign.</p></body></html>"))
        self.pushButton_surveys_disable_all.setText(_translate("MainWindow", "Deactivate all"))
        self.tabWidget_observations.setTabText(self.tabWidget_observations.indexOf(self.tab_surveys), _translate("MainWindow", "Surveys"))
        self.groupBox_obs_setups_applied_corrections.setToolTip(_translate("MainWindow", "Information on the corrections that have been applied on the observations on which the setup data is based on."))
        self.groupBox_obs_setups_applied_corrections.setTitle(_translate("MainWindow", "Applied corrections:"))
        self.label_obs_setups_1.setToolTip(_translate("MainWindow", "Type of applied tidal corrections."))
        self.label_obs_setups_1.setText(_translate("MainWindow", "Tidal correction:"))
        self.label_obs_setups_tidal_corr.setToolTip(_translate("MainWindow", "Type of applied tidal corrections."))
        self.label_obs_setups_2.setToolTip(_translate("MainWindow", "Type of the applied reference height reduction."))
        self.label_obs_setups_2.setText(_translate("MainWindow", "Obs. reference height:"))
        self.label_obs_setups_ref_height.setToolTip(_translate("MainWindow", "Type of the applied reference height reduction."))
        self.label_27.setText(_translate("MainWindow", "Scale Correction:"))
        self.label_obs_setups_3.setText(_translate("MainWindow", "Atm. pressure correction: "))
        self.label_29.setText(_translate("MainWindow", "Ocean-loading correction:"))
        self.tabWidget_observations.setTabText(self.tabWidget_observations.indexOf(self.tab_observations_setups), _translate("MainWindow", "Setups table"))
        self.tabWidget_Main.setTabText(self.tabWidget_Main.indexOf(self.tab_main_observations), _translate("MainWindow", "Observations"))
        self.groupBox_results_lsm_runs.setTitle(_translate("MainWindow", "LSM runs"))
        self.pushButton_results_delete_lsm_run.setToolTip(_translate("MainWindow", "<html><head/><body><p>Delete the selected LSM run.</p></body></html>"))
        self.pushButton_results_delete_lsm_run.setText(_translate("MainWindow", "Delete selected lsm run"))
        self.pushButton_results_delete_all_lsm_runs.setToolTip(_translate("MainWindow", "<html><head/><body><p>Delete ALL lsm runs in the campaign.</p></body></html>"))
        self.pushButton_results_delete_all_lsm_runs.setText(_translate("MainWindow", "Delete all lsm runs"))
        self.groupBox_results_data_selection.setTitle(_translate("MainWindow", "Data selection"))
        self.label_2.setText(_translate("MainWindow", "Station"))
        self.comboBox_results_selection_station.setItemText(0, _translate("MainWindow", "All stations"))
        self.label_5.setText(_translate("MainWindow", "Survey"))
        self.comboBox_results_selection_survey.setItemText(0, _translate("MainWindow", "All surveys"))
        self.groupBox_gis_data.setToolTip(_translate("MainWindow", "<html><head/><body><p>Export the current content of the observations and the stations table to an ESRI shapefile (obs_results.shp and stat_results.shp). Please declare the CRS of the station coordinates by a valid EPSG code. The files are written to the campaign\'s output directory. </p></body></html>"))
        self.groupBox_gis_data.setTitle(_translate("MainWindow", "GIS data"))
        self.pushButton_results_export_shapefile.setToolTip(_translate("MainWindow", "<html><head/><body><p>Export  the current content of the observations and the stations table to an ESRI shapefile (&lt;campaign name&gt;_obs.shp and &lt;campaign name&gt;_stat.shp).</p></body></html>"))
        self.pushButton_results_export_shapefile.setText(_translate("MainWindow", "Export shapefile"))
        self.groupBox_results_info.setTitle(_translate("MainWindow", "Info"))
        self.label_3.setToolTip(_translate("MainWindow", "Adjustment method."))
        self.label_3.setText(_translate("MainWindow", "Adjustment method:"))
        self.label_8.setToolTip(_translate("MainWindow", "Number of iterations in case the iterative adjustemnt of s0² was selected."))
        self.label_8.setText(_translate("MainWindow", "Number of iterations:"))
        self.label_10.setToolTip(_translate("MainWindow", "Optional comment on the lsm run."))
        self.label_10.setText(_translate("MainWindow", "Comment: "))
        self.label_4.setToolTip(_translate("MainWindow", "Time and date the adjustment was carried out."))
        self.label_4.setText(_translate("MainWindow", "Time and Date:"))
        self.groupBox_results_statistics.setTitle(_translate("MainWindow", "Statistics and tests"))
        self.label_9.setToolTip(_translate("MainWindow", "A posteriori variance of unit weight."))
        self.label_9.setText(_translate("MainWindow", "s0²:"))
        self.label_6.setToolTip(_translate("MainWindow", "Outcome of the global model test."))
        self.label_6.setText(_translate("MainWindow", "Goodness-of-fit test:"))
        self.label_7.setToolTip(_translate("MainWindow", "Number of detected outliers."))
        self.label_7.setText(_translate("MainWindow", "Number of outliers:"))
        self.groupBox_results_lsm_run_log.setTitle(_translate("MainWindow", "LSM run log"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_info), _translate("MainWindow", "Info"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_obs_table), _translate("MainWindow", "Observations Table"))
        self.groupBox_plot_settings.setTitle(_translate("MainWindow", "Plot settings"))
        self.label_results_obs_plot_selec_data_column.setText(_translate("MainWindow", "Select data column:"))
        self.radioButton_results_obs_plot_timeseries.setText(_translate("MainWindow", "Time series"))
        self.radioButton_results_obs_plot_histogram.setText(_translate("MainWindow", "Histogram"))
        self.groupBox_histogram_settings.setTitle(_translate("MainWindow", "Histogram settings"))
        self.label_11.setText(_translate("MainWindow", "Method"))
        self.label_results_obs_plot_number_bins.setText(_translate("MainWindow", "Number of bins"))
        self.checkBox_results_obs_plot_show_outliers.setText(_translate("MainWindow", "Show outliers"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_obs_plots), _translate("MainWindow", "Observations Plots"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_drift), _translate("MainWindow", "Drift Table"))
        self.graphicsLayoutWidget_results_drift_plot.setToolTip(_translate("MainWindow", "<html><head/><body><p>This plot depicts setup observations and the the drift function (polynomial of degree n) fitted to these observations.</p></body></html>"))
        self.groupBox_results_drift_plot.setTitle(_translate("MainWindow", "Drift plot settings"))
        self.label_results_drift_plot_v_offset.setToolTip(_translate("MainWindow", "<html><head/><body><p>Add vertical offset to the drift function (polynomial) w.r.t. the setup observations. This is needed to when differential observations are used for prameter estimation. In this case the constant bias of the gravimeter reading cannot be estimated and is only determined approximately.</p></body></html>"))
        self.label_results_drift_plot_v_offset.setText(_translate("MainWindow", "Vertical offset of drift polynomial w.r.t. setup observations [µGal]"))
        self.spinBox_results_drift_plot_v_offset.setToolTip(_translate("MainWindow", "<html><head/><body><p>Add vertical offset to the drift function (polynomial) w.r.t. the setup observations. This is needed to when differential observations are used for prameter estimation. In this case the constant bias of the gravimeter reading cannot be estimated and is only determined approximately.</p></body></html>"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_driftplot), _translate("MainWindow", "Drift Plot"))
        self.groupBox_results_stations_statistics.setToolTip(_translate("MainWindow", "<html><head/><body><p>Calculate and display descriptive statistics for the selected data column.</p></body></html>"))
        self.groupBox_results_stations_statistics.setTitle(_translate("MainWindow", "Statistics"))
        self.label_12.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select data column for displaying statistics.</p></body></html>"))
        self.label_12.setText(_translate("MainWindow", "Select column"))
        self.comboBox_results_stations_statistics_select_col.setToolTip(_translate("MainWindow", "<html><head/><body><p>Select data column for displaying statistics.</p></body></html>"))
        self.label_13.setToolTip(_translate("MainWindow", "Mean"))
        self.label_13.setText(_translate("MainWindow", "Mean:"))
        self.label_results_stations_statistics_mean.setToolTip(_translate("MainWindow", "Mean"))
        self.label_14.setToolTip(_translate("MainWindow", "Standard deviation"))
        self.label_14.setText(_translate("MainWindow", "Std.:"))
        self.label_results_stations_statistics_std.setToolTip(_translate("MainWindow", "Standard deviation"))
        self.label_15.setToolTip(_translate("MainWindow", "Minimum"))
        self.label_15.setText(_translate("MainWindow", "Min.:"))
        self.label_results_stations_statistics_min.setToolTip(_translate("MainWindow", "Minimum"))
        self.label_16.setToolTip(_translate("MainWindow", "Maximum"))
        self.label_16.setText(_translate("MainWindow", "Max.:"))
        self.label_results_stations_statistics_max.setToolTip(_translate("MainWindow", "Maximum"))
        self.label_17.setToolTip(_translate("MainWindow", "Median"))
        self.label_17.setText(_translate("MainWindow", "Median:"))
        self.label__results_stations_statistics_median.setToolTip(_translate("MainWindow", "Median"))
        self.label_18.setToolTip(_translate("MainWindow", "Interquartile range"))
        self.label_18.setText(_translate("MainWindow", "IQR:"))
        self.label__results_stations_statistics_iqr.setToolTip(_translate("MainWindow", "Interquartile range"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_stat_table), _translate("MainWindow", " Stations Table"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_results_correlation_matrix), _translate("MainWindow", "Correlation Matrix"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_vg_table), _translate("MainWindow", "VG Table"))
        self.graphicsLayoutWidget_results_vg_plot.setToolTip(_translate("MainWindow", "The VG plot illustartes the estimation results of the VG polynomial."))
        self.groupBox_results_vg_plot_settings.setToolTip(_translate("MainWindow", "Settings for the VG plot."))
        self.groupBox_results_vg_plot_settings.setTitle(_translate("MainWindow", "VG plot settings"))
        self.checkBox_results_vg_plot_show_residuals.setToolTip(_translate("MainWindow", "Plot the post fit residuals grouped by the setup height (station name). If linear and no-linear components of the VG polynomial (degree > 1) are plotted separately, the residuals w.r.t. the linear component estimated in the LSM adjustment are shown."))
        self.checkBox_results_vg_plot_show_residuals.setText(_translate("MainWindow", "Show residuals"))
        self.radioButton_results_vg_plot_details.setToolTip(_translate("MainWindow", "Plot the linear and non-linear components of the estimates VG polynomial separately. "))
        self.radioButton_results_vg_plot_details.setText(_translate("MainWindow", "Plot linear and non-linear components separately"))
        self.radioButton_results_vg_plot_full_polynomial.setToolTip(_translate("MainWindow", "Plot the full estimated VG polynomial versus height above the reference."))
        self.radioButton_results_vg_plot_full_polynomial.setText(_translate("MainWindow", "Plot full polynomial"))
        self.tabWidget_results.setTabText(self.tabWidget_results.indexOf(self.tab_vg_plot), _translate("MainWindow", "VG Plot"))
        self.tabWidget_Main.setTabText(self.tabWidget_Main.indexOf(self.tab_main_results), _translate("MainWindow", "Results"))
        self.tabWidget_Main.setTabToolTip(self.tabWidget_Main.indexOf(self.tab_main_results), _translate("MainWindow", "Setup data: Corrected and reduces observation data accumulated for each instrument setup."))
        self.menu_File.setTitle(_translate("MainWindow", "File"))
        self.menuAdd_Survey.setTitle(_translate("MainWindow", "Add Survey"))
        self.menu_Add_Stations.setTitle(_translate("MainWindow", "Add Stations"))
        self.menu_Add_Gravimeters.setTitle(_translate("MainWindow", "Add Gravimeters"))
        self.menu_Observations.setTitle(_translate("MainWindow", "Observations"))
        self.menuEstimation_settings.setTitle(_translate("MainWindow", "Settings"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.menuCorrections.setTitle(_translate("MainWindow", "Corrections"))
        self.action_New_Campaign.setText(_translate("MainWindow", "&New Campaign"))
        self.action_Save_Campaign.setText(_translate("MainWindow", "&Save Campaign"))
        self.action_Load_Campaign.setText(_translate("MainWindow", "&Load Campaign"))
        self.action_Load_Campaign.setToolTip(_translate("MainWindow", "Load campaign"))
        self.action_Add_Stations.setText(_translate("MainWindow", "Add Stations"))
        self.action_Exit.setText(_translate("MainWindow", "E&xit"))
        self.action_Exit.setToolTip(_translate("MainWindow", "Exit GravTools"))
        self.action_Edit_Observations.setText(_translate("MainWindow", "Edit Observations"))
        self.actionResiduals.setText(_translate("MainWindow", "Residuals"))
        self.actionEstimates.setText(_translate("MainWindow", "Estimates"))
        self.action_Corrections.setText(_translate("MainWindow", "Correction settings"))
        self.actionShow_Stations.setText(_translate("MainWindow", "Show Stations"))
        self.action_from_CG5_observation_file.setText(_translate("MainWindow", "from CG5 observation files"))
        self.action_from_BEV_observation_file.setText(_translate("MainWindow", "from BEV observation file"))
        self.action_Autoselection_settings.setText(_translate("MainWindow", "Autoselection settings"))
        self.action_Autoselection_settings.setToolTip(_translate("MainWindow", "Autoselection settings."))
        self.action_Estimation_settings.setText(_translate("MainWindow", "Estimation settings"))
        self.actionEstimate_long_term_drift.setText(_translate("MainWindow", "Estimate long-term drift"))
        self.action_Export_Results.setText(_translate("MainWindow", "Export Data"))
        self.action_Export_Results.setToolTip(_translate("MainWindow", "Export data"))
        self.action_Change_output_directory.setText(_translate("MainWindow", "Change output directory"))
        self.action_Options.setText(_translate("MainWindow", "Options"))
        self.action_Setup_data_options.setText(_translate("MainWindow", "Setup data options"))
        self.action_Setup_data_options.setToolTip(_translate("MainWindow", "Options for the determination of setup data/observations."))
        self.action_Flag_observations.setText(_translate("MainWindow", "Load flags from obs. list file"))
        self.action_Flag_observations.setToolTip(_translate("MainWindow", "Flag observations based ob observations file"))
        self.action_Change_Campaign_name.setText(_translate("MainWindow", "Change Campaign name"))
        self.action_About.setText(_translate("MainWindow", "About"))
        self.action_License.setText(_translate("MainWindow", "License"))
        self.action_Gis_Export_settings.setText(_translate("MainWindow", "GIS export settings"))
        self.action_from_oesgn_table.setText(_translate("MainWindow", "From OESGN file"))
        self.action_from_csv_file.setText(_translate("MainWindow", "From CSV file"))
        self.action_Correction_time_series.setText(_translate("MainWindow", "Correction time series"))
        self.action_Correction_time_series.setToolTip(_translate("MainWindow", "Manage correction time series data"))
        self.action_gravimeters_from_json_file.setText(_translate("MainWindow", "From json file"))
        self.action_from_CG6_observation_files.setText(_translate("MainWindow", "from CG6 observation files"))
        self.action_Calculate_drift.setText(_translate("MainWindow", "Calculate drift"))
        self.action_Calculate_drift.setToolTip(_translate("MainWindow", "Drift determination based on the reduced observations. Usefull for calibrating instrumental drift parameters."))
from pyqtgraph import GraphicsLayoutWidget



"""
Plotting utilities for gravtools.
This module is part of the gravtools package.
Author: Andreas Hellerschmied
"""

import numpy as np
import matplotlib.pyplot as plt

# Imports from other gravtools modules:
from bev_legacy import utils


def create_drift_plot(obs_df, stat_df, poly_coef_dict, save_pdf=True, session_name='', path_save_file=''):
    """
    Erstellen eines Drift-Plots.
    :param path_save_file: filepath for saving teh plot
    :param session_name: Name of the observing session (e.g. obs-file name)
    :param obs_df: observation dataframe
    :param stat_df: station dataframe
    :param poly_coef_dict: dict with coefficients of drift polanomial
    :param save_pdf: flag, save plot as PDF?
    :return:
    """
    # Check input arguments
    if save_pdf and (len(session_name) == 0):
        print('ERROR: Name for output PDF file (drift plot) is not defined!')
        exit()

    # Evaluate drift polynomial:
    pol_degree = len(poly_coef_dict)
    poly_coef = utils.prep_polyval_coef(poly_coef_dict)
    dt_h = np.linspace(obs_df.dt_h.min(), obs_df.dt_h.max(), 100)
    yy_mugal = np.polyval(poly_coef, dt_h)

    g_plot_min = 0.0
    g_plot_max = 0.0

    fig, ax = plt.subplots()
    ax.plot(dt_h, yy_mugal, '--', label='Polynom (n={})'.format(pol_degree))
    for pkt_num in stat_df.punktnummer:
        # print(pkt_num)
        df_tmp = obs_df.loc[obs_df['punktnummer'] == pkt_num]
        g_est = stat_df.loc[stat_df['punktnummer'] == pkt_num].g_est_mugal.values[0]
        if stat_df.loc[stat_df['punktnummer'] == pkt_num].is_drift_point.bool():
            label_str = pkt_num + '*'
        else:
            label_str = pkt_num
        y_tmp = df_tmp.g_red_mugal - g_est
        ax.plot(df_tmp.dt_h, y_tmp, 'o', label=label_str)
        if y_tmp.max() > g_plot_max:
            g_plot_max = y_tmp.max()
        if y_tmp.min() < g_plot_min:
            g_plot_min = y_tmp.min()

    gangbreite_mugal = g_plot_max - g_plot_min

    # - Legend and labels:
    plt.legend(loc='best')
    # ax.legend(loc='upper left', bbox_to_anchor=(1, 0.5))
    ax.grid()
    plt.title('Drift-Polynom: {} (Gangbreite: {:4.1f} µGal)'.format(session_name, gangbreite_mugal))
    plt.xlabel('Zeit [h]')
    plt.ylabel('Lesung [µGal]')

    # Save as PDF file:
    if save_pdf:
        plt.savefig(path_save_file + session_name + '_drift.pdf')

    # plt.show(block=True)  # Keep plot open



"""Example script for creating a corretcion time series by loading data from TSF files.

Copyright (C) 2023  Andreas Hellerschmied <andreas.hellerschmied@bev.gv.at>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
from datetime import datetime

import numpy as np

from gravtools.tides.tide_data_tfs import TSF
from gravtools.tides.correction_time_series import CorrectionTimeSeries

def main():
    """Main function"""

    # Load file with integer seconds time reference:
    FILENAME_TFS = '../../data/tfs_files/l230406.TSF'

    corr_time_series = CorrectionTimeSeries()
    corr_time_series.load_tfs_file('l230406', FILENAME_TFS, instrument='Theory-Loading')

    corr_time_series.surveys['l230406'].stations['BEV_U3'].tidal_correction.to_df()

    corr_time_series.load_tfs_file('l230406', FILENAME_TFS, instrument='Theory-Loading')


    interp_times = np.array([datetime.strptime('2023-04-06 00:00:30', '%Y-%m-%d %H:%M:%S'),
                    datetime.strptime('2023-04-06 00:01:30', '%Y-%m-%d %H:%M:%S'),
                    datetime.strptime('2023-04-06 00:02:30', '%Y-%m-%d %H:%M:%S')])  # or list()

    interpol_y = corr_time_series.surveys['l230406'].stations['BEV_U3'].tidal_correction.interpolate(interp_times=interp_times)
    print(interpol_y)

    print('end')





if __name__ == '__main__':
    main()


"""Model classes for PyQt's model view architecture.

Copyright (C) 2021  Andreas Hellerschmied <andreas.hellerschmied@bev.gv.at>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from PyQt5.QtCore import QAbstractTableModel, Qt
from PyQt5 import QtGui
from PyQt5.QtWidgets import QMessageBox

from gravtools import settings
from gravtools.models.misc import time_it

NONE_REPRESENTATION_IN_TABLE_VIEW = ''  # Representation of None values in table views in the GUI


class ResultsCorrelationMatrixModel(QAbstractTableModel):
    """Model for displaying the correlation matrix table."""

    # Number of decimal places for displaying the correlation coefficients
    _DECIMAL_PLACES_CORR_COEF = 3

    def __init__(self, lsm_runs):
        """Initialize the correlation matrix table view model.

        Parameters
        ----------
        lsm_runs : list of py.obj:`gravtools.lsm.LSM` objects
        """
        QAbstractTableModel.__init__(self)
        self._lsm_runs = []
        self._data = None  # Observations (or at subset of them) of the survey with the name `self._data_survey_name`
        self.load_lsm_runs(lsm_runs)
        self._lsm_run_index = None  # Name of the Survey that is currently represented by `self._data`
        self._data_column_names = None

    # @time_it
    def load_lsm_runs(self, lsm_runs: list):
        """Load adjustment results.

        Notes
        -----
        The data is assigned by reference, i.e. all changes in `_surveys` will propagate to the data origin.
        """
        self._lsm_runs = lsm_runs

    # @time_it
    def update_view_model(self, lsm_run_index: int, station_name=None, survey_name=None):
        """Update the `_data` DataFrame that hold the actual data that is displayed.

        Notes
        -----
        Data selection based on a station name or on a survey name is not implemented yet.
        """

        if lsm_run_index == -1:  # No data available => Invalid index => Reset model data
            self._data = None
            self._lsm_run_index = None
            self._data_column_names = None
        else:
            try:
                self._data = self._lsm_runs[lsm_run_index].get_correlation_matrix  # Rxx matrix (np.array)
                if hasattr(self._lsm_runs[lsm_run_index], 'x_estimate_names'):
                    self._data_column_names = self._lsm_runs[
                        lsm_run_index].x_estimate_names  # Names of estimates in same order as in Rxx
                else:
                    self._data_column_names = None
            except KeyError:
                self._data = None
                self._data_column_names = None
                QMessageBox.critical(self.parent(), 'Error!', f'LSM run with index "{lsm_run_index}" not found!')
            except Exception as e:
                QMessageBox.critical(self.parent(), 'Error!', str(e))
                self._data = None
                self._data_column_names = None
            else:
                self._lsm_run_index = lsm_run_index

    def rowCount(self, parent=None):
        if self._data is not None:
            return self._data.shape[0]
        else:
            return 0

    def columnCount(self, parent=None):
        if self._data is not None:
            return self._data.shape[1]
        else:
            return 0

    def data(self, index, role=Qt.DisplayRole):
        if index.isValid():
            if role == Qt.DisplayRole:
                value = self._data[index.row(), index.column()]  # np.array
                # column_name = self._data_column_names[index.column()]
                # Custom formatter (string is expected as return type):
                if value is None:  #
                    return NONE_REPRESENTATION_IN_TABLE_VIEW
                elif isinstance(value, float):
                    if value != value:  # True, if value is "NaN"
                        return NONE_REPRESENTATION_IN_TABLE_VIEW
                    else:
                        return '{1:.{0}f}'.format(self._DECIMAL_PLACES_CORR_COEF, value)
                else:  # all other
                    return str(value)

            if role == Qt.TextAlignmentRole:
                value = self._data[index.row(), index.column()]
                if isinstance(value, int) or isinstance(value, float):
                    # Align right, vertical middle.
                    return Qt.AlignVCenter + Qt.AlignRight

            if role == Qt.BackgroundRole:
                if index.row() == index.column():
                    return QtGui.QColor(settings.CORRELATION_COEF_DIAG_ELEMENTS)
                else:
                    value = self._data[index.row(), index.column()]
                    if isinstance(value, int) or isinstance(value, float):
                        # Get absolute value:
                        value = abs(value)
                        color_idx = int(value * len(settings.CORRELATION_COEF_COLORS))
                        color_idx = max(0, color_idx)  # color_idx < 0 become 0
                        color_idx = min(len(settings.CORRELATION_COEF_COLORS)-1, color_idx)
                        return QtGui.QColor(settings.CORRELATION_COEF_COLORS[color_idx])
        return None

    def headerData(self, section, orientation, role):
        # section is the index of the column/row.
        if role == Qt.DisplayRole:
            if self._data_column_names is None:
                return str(section)
            else:
                if orientation == Qt.Horizontal:
                    # return self._SHOW_COLUMNS_IN_TABLE_DICT[str(self._data.columns[section])]
                    return str(self._data_column_names[section])
                if orientation == Qt.Vertical:
                    # return str(self._data.index[section])
                    return str(self._data_column_names[section])




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gravtools/gui/dialog_calc_drift.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog_calculate_drift(object):
    def setupUi(self, Dialog_calculate_drift):
        Dialog_calculate_drift.setObjectName("Dialog_calculate_drift")
        Dialog_calculate_drift.resize(1280, 697)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Dialog_calculate_drift)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox_data_selection = QtWidgets.QGroupBox(Dialog_calculate_drift)
        self.groupBox_data_selection.setObjectName("groupBox_data_selection")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.groupBox_data_selection)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_survey = QtWidgets.QLabel(self.groupBox_data_selection)
        self.label_survey.setObjectName("label_survey")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_survey)
        self.comboBox_survey = QtWidgets.QComboBox(self.groupBox_data_selection)
        self.comboBox_survey.setObjectName("comboBox_survey")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.comboBox_survey)
        self.label_station = QtWidgets.QLabel(self.groupBox_data_selection)
        self.label_station.setObjectName("label_station")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_station)
        self.comboBox_station = QtWidgets.QComboBox(self.groupBox_data_selection)
        self.comboBox_station.setObjectName("comboBox_station")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.comboBox_station)
        self.verticalLayout_4.addLayout(self.formLayout)
        self.checkBox_multiple_setups_only = QtWidgets.QCheckBox(self.groupBox_data_selection)
        self.checkBox_multiple_setups_only.setChecked(True)
        self.checkBox_multiple_setups_only.setObjectName("checkBox_multiple_setups_only")
        self.verticalLayout_4.addWidget(self.checkBox_multiple_setups_only)
        self.checkBox_active_obs_only = QtWidgets.QCheckBox(self.groupBox_data_selection)
        self.checkBox_active_obs_only.setChecked(True)
        self.checkBox_active_obs_only.setObjectName("checkBox_active_obs_only")
        self.verticalLayout_4.addWidget(self.checkBox_active_obs_only)
        self.verticalLayout.addWidget(self.groupBox_data_selection)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.groupBox_options = QtWidgets.QGroupBox(Dialog_calculate_drift)
        self.groupBox_options.setObjectName("groupBox_options")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.groupBox_options)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.label_degree = QtWidgets.QLabel(self.groupBox_options)
        self.label_degree.setObjectName("label_degree")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_degree)
        self.spinBox_degree = QtWidgets.QSpinBox(self.groupBox_options)
        self.spinBox_degree.setMinimum(1)
        self.spinBox_degree.setMaximum(3)
        self.spinBox_degree.setObjectName("spinBox_degree")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.spinBox_degree)
        self.label_method = QtWidgets.QLabel(self.groupBox_options)
        self.label_method.setObjectName("label_method")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_method)
        self.comboBox_method = QtWidgets.QComboBox(self.groupBox_options)
        self.comboBox_method.setObjectName("comboBox_method")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.comboBox_method)
        self.label_min_no_obs = QtWidgets.QLabel(self.groupBox_options)
        self.label_min_no_obs.setObjectName("label_min_no_obs")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.label_min_no_obs)
        self.spinBox_min_no_obs = QtWidgets.QSpinBox(self.groupBox_options)
        self.spinBox_min_no_obs.setMinimum(1)
        self.spinBox_min_no_obs.setProperty("value", 2)
        self.spinBox_min_no_obs.setObjectName("spinBox_min_no_obs")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.spinBox_min_no_obs)
        self.verticalLayout_3.addLayout(self.formLayout_2)
        self.checkBox_remove_g_offset = QtWidgets.QCheckBox(self.groupBox_options)
        self.checkBox_remove_g_offset.setObjectName("checkBox_remove_g_offset")
        self.verticalLayout_3.addWidget(self.checkBox_remove_g_offset)
        self.horizontalLayout.addWidget(self.groupBox_options)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.graphicsLayoutWidget_drift_plot = GraphicsLayoutWidget(Dialog_calculate_drift)
        self.graphicsLayoutWidget_drift_plot.setObjectName("graphicsLayoutWidget_drift_plot")
        self.verticalLayout_2.addWidget(self.graphicsLayoutWidget_drift_plot)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog_calculate_drift)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Save)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)

        self.retranslateUi(Dialog_calculate_drift)
        self.buttonBox.accepted.connect(Dialog_calculate_drift.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog_calculate_drift.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog_calculate_drift)

    def retranslateUi(self, Dialog_calculate_drift):
        _translate = QtCore.QCoreApplication.translate
        Dialog_calculate_drift.setWindowTitle(_translate("Dialog_calculate_drift", "Calculate drift"))
        self.groupBox_data_selection.setToolTip(_translate("Dialog_calculate_drift", "Options for selection of observation data that is used for calculating the drift."))
        self.groupBox_data_selection.setTitle(_translate("Dialog_calculate_drift", "Data selection"))
        self.label_survey.setToolTip(_translate("Dialog_calculate_drift", "Select a survey."))
        self.label_survey.setText(_translate("Dialog_calculate_drift", "Survey"))
        self.comboBox_survey.setToolTip(_translate("Dialog_calculate_drift", "Select a survey."))
        self.label_station.setToolTip(_translate("Dialog_calculate_drift", "Either select all stations or one station for drift determination."))
        self.label_station.setText(_translate("Dialog_calculate_drift", "Station"))
        self.comboBox_station.setToolTip(_translate("Dialog_calculate_drift", "Either select all stations or one station for drift determination."))
        self.checkBox_multiple_setups_only.setToolTip(_translate("Dialog_calculate_drift", "Only consider stations with multiple instrument setups."))
        self.checkBox_multiple_setups_only.setText(_translate("Dialog_calculate_drift", "Stations with multiple setups only"))
        self.checkBox_active_obs_only.setToolTip(_translate("Dialog_calculate_drift", "Only consider active observations (based on the selection in the observations tab in the main window)."))
        self.checkBox_active_obs_only.setText(_translate("Dialog_calculate_drift", "Only consider active observations"))
        self.groupBox_options.setToolTip(_translate("Dialog_calculate_drift", "<html><head/><body><p>Options for the drift calculation and the visualization in the plotwindows below. The drift is modelled as time dependent polynomial of the specified degree.</p></body></html>"))
        self.groupBox_options.setTitle(_translate("Dialog_calculate_drift", "Options"))
        self.label_degree.setToolTip(_translate("Dialog_calculate_drift", "Degree of the drift polynomial."))
        self.label_degree.setText(_translate("Dialog_calculate_drift", "Poly. degree"))
        self.spinBox_degree.setToolTip(_translate("Dialog_calculate_drift", "Degree of the drift polynomial."))
        self.label_method.setToolTip(_translate("Dialog_calculate_drift", "Drift calculation method."))
        self.label_method.setText(_translate("Dialog_calculate_drift", "Drift calc. method"))
        self.comboBox_method.setToolTip(_translate("Dialog_calculate_drift", "Drift calculation method."))
        self.label_min_no_obs.setToolTip(_translate("Dialog_calculate_drift", "<html><head/><body><p>Minimum number of observations required to fit a drift polynomial.</p></body></html>"))
        self.label_min_no_obs.setText(_translate("Dialog_calculate_drift", "Min. n/o observations"))
        self.spinBox_min_no_obs.setToolTip(_translate("Dialog_calculate_drift", "<html><head/><body><p>Minimum number of observations required to fit a drift polynomial.</p></body></html>"))
        self.checkBox_remove_g_offset.setToolTip(_translate("Dialog_calculate_drift", "<html><head/><body><p>Remove gravity offsets between the drift functions and observations of different stations. The first station in the dropdown list is used as reference and remains unchanged. This allows for depicting drift functions of multiple stations as an overlay.</p></body></html>"))
        self.checkBox_remove_g_offset.setText(_translate("Dialog_calculate_drift", "Remove gravity offsets between stations in the plot"))
        self.graphicsLayoutWidget_drift_plot.setToolTip(_translate("Dialog_calculate_drift", "Drift plot depicting the observerd gravity values at stations and the fitted drift polynomials a functions of time."))
        self.buttonBox.setToolTip(_translate("Dialog_calculate_drift", "<html><head/><body><p>Click <span style=\" font-weight:600; font-style:italic;\">Save</span> to create a drift report file and a drift plot file in the campaign directory. Click <span style=\" font-weight:600; font-style:italic;\">Cancel</span> to close this windows.</p></body></html>"))
from pyqtgraph import GraphicsLayoutWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'gravtools/gui/dialog_new_campaign.ui'
#
# Created by: PyQt5 UI code generator 5.15.9
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog_new_Campaign(object):
    def setupUi(self, Dialog_new_Campaign):
        Dialog_new_Campaign.setObjectName("Dialog_new_Campaign")
        Dialog_new_Campaign.resize(374, 162)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Dialog_new_Campaign)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setSpacing(20)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formLayout = QtWidgets.QFormLayout()
        self.formLayout.setObjectName("formLayout")
        self.label_campaign_name = QtWidgets.QLabel(Dialog_new_Campaign)
        self.label_campaign_name.setObjectName("label_campaign_name")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.label_campaign_name)
        self.lineEdit_campaign_name = QtWidgets.QLineEdit(Dialog_new_Campaign)
        self.lineEdit_campaign_name.setMaxLength(15)
        self.lineEdit_campaign_name.setObjectName("lineEdit_campaign_name")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lineEdit_campaign_name)
        self.label_output_directory = QtWidgets.QLabel(Dialog_new_Campaign)
        self.label_output_directory.setObjectName("label_output_directory")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.label_output_directory)
        self.lineEdit_output_directory = QtWidgets.QLineEdit(Dialog_new_Campaign)
        self.lineEdit_output_directory.setMaxLength(300)
        self.lineEdit_output_directory.setObjectName("lineEdit_output_directory")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.lineEdit_output_directory)
        self.pushButton_change_output_directory = QtWidgets.QPushButton(Dialog_new_Campaign)
        self.pushButton_change_output_directory.setMinimumSize(QtCore.QSize(0, 0))
        self.pushButton_change_output_directory.setObjectName("pushButton_change_output_directory")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.pushButton_change_output_directory)
        self.verticalLayout.addLayout(self.formLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog_new_Campaign)
        self.buttonBox.setEnabled(True)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setCenterButtons(False)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout.addWidget(self.buttonBox)
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.label_campaign_name.setBuddy(self.lineEdit_campaign_name)
        self.label_output_directory.setBuddy(self.lineEdit_output_directory)

        self.retranslateUi(Dialog_new_Campaign)
        self.buttonBox.accepted.connect(Dialog_new_Campaign.accept) # type: ignore
        self.buttonBox.rejected.connect(Dialog_new_Campaign.reject) # type: ignore
        QtCore.QMetaObject.connectSlotsByName(Dialog_new_Campaign)

    def retranslateUi(self, Dialog_new_Campaign):
        _translate = QtCore.QCoreApplication.translate
        Dialog_new_Campaign.setWindowTitle(_translate("Dialog_new_Campaign", "New campaign"))
        self.label_campaign_name.setText(_translate("Dialog_new_Campaign", "Campaign &name:"))
        self.lineEdit_campaign_name.setToolTip(_translate("Dialog_new_Campaign", "Enter name of the new camapign (max. 15 characters)."))
        self.label_output_directory.setText(_translate("Dialog_new_Campaign", "Output &directory:"))
        self.lineEdit_output_directory.setToolTip(_translate("Dialog_new_Campaign", "Enter the path to the output directory or use the dialog below."))
        self.pushButton_change_output_directory.setToolTip(_translate("Dialog_new_Campaign", "Open dialog to select the output directory."))
        self.pushButton_change_output_directory.setText(_translate("Dialog_new_Campaign", "&Change output directory..."))



"""Example script for loading TSoft TSF files with tidal data.

Copyright (C) 2023  Andreas Hellerschmied <andreas.hellerschmied@bev.gv.at>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from gravtools.tides.tide_data_tfs import TSF

def main():
    """Main function"""

    # Load file with integer seconds time reference:
    FILENAME_TFS = '../../data/tfs_files/TEST_SITE_1.TSF'
    tfs_data = TSF.from_tfs_file(FILENAME_TFS)
    print(tfs_data.filename)
    print(tfs_data)
    print(tfs_data.get_channel_df(1))

    # Load file with integer sub-seconds time reference:
    FILENAME_TFS = '../../data/tfs_files/TEST_SITE_1_subsecond.TSF'
    tfs_data = TSF.from_tfs_file(FILENAME_TFS)
    print(tfs_data.filename)
    print(tfs_data)
    print(tfs_data.get_channel_df('last'))
    print(tfs_data.get_channel_df('TEST_SITE_1:Theory Sol. Earth:WDD'))

    print('end')

if __name__ == '__main__':
    main()